@@ -24,6 +24,7 @@ def prep_estim(
     l_max=3,
     k_max=16,
     dry_run=True,
+    use_prior_transform=None,
     verbose=True,
     debug=False,
     **filterargs
@@ -81,9 +82,16 @@ def prep_estim(
     if not "reduced_form" in filterargs:
         filterargs["reduced_form"] = True
 
+    if use_prior_transform is None:
+        if "use_prior_transform" in self.fdict.keys():
+            use_prior_transform = self.fdict["use_prior_transform"]
+        else:
+            use_prior_transform = False
+
     self.fdict["filter_n"] = N
     self.fdict["linear"] = linear
     self.fdict["seed"] = seed
+    self.fdict["use_prior_transform"] = use_prior_transform
 
     self.debug |= debug
 
@@ -127,19 +135,18 @@ def prep_estim(
 
     self.ndim = len(prior.keys())
 
-    if "frozen_prior" not in self.fdict.keys() or eval_priors:
+    pfrozen, lprior, bptrans, pinitv, bounds = get_prior(
+        prior, verbose=verbose)
+    self.fdict["frozen_prior"] = pfrozen
+    self.fdict["prior_bounds"] = bounds
+    self.fdict["init_value"] = pinitv
 
-        pfrozen, _, pinitv, bounds = get_prior(prior, verbose=verbose)
-        self.fdict["frozen_prior"] = pfrozen
-        self.fdict["prior_bounds"] = bounds
-        self.fdict["init_value"] = pinitv
-
-        if verbose:
-            print(
-                "[estimation:]".ljust(15, " ")
-                + " %s priors detected. Adding parameters to the prior distribution."
-                % self.ndim
-            )
+    if verbose:
+        print(
+            "[estimation:]".ljust(15, " ")
+            + " %s priors detected. Adding parameters to the prior distribution."
+            % self.ndim
+        )
 
     def llike(parameters, par_fix, linear, verbose, seed):
 
@@ -179,19 +186,14 @@ def prep_estim(
                 np.random.set_state(random_state)
                 return -np.inf
 
-    def lprior(par):
-
-        prior = 0
-        for i, pl in enumerate(self.fdict["frozen_prior"]):
-            prior += pl.logpdf(par[i])
-
-        return prior
-
     linear_pa = linear
 
     def lprob(
             par, par_fix=par_fix, linear=None, verbose=verbose > 1, temp=1):
 
+        if use_prior_transform:
+            par = bptrans(par)
+
         lp = lprior(par)
 
         if np.isinf(lp):
@@ -223,8 +225,9 @@ def prep_estim(
 
     # make functions accessible
     self.lprob = lprob
-    self.lprior = lprior
     self.llike = llike
+    self.lprior = lprior
+    self.bptrans = bptrans if use_prior_transform else None
 
     if not debug and (ncores is None or ncores):
         create_pool(self, ncores)
